"use client";

import { useInfiniteQuery } from "@tanstack/react-query";
import { searchPrograms } from "@/lib/api/programs";
import { Program } from "@/types/program";

interface UseProgramSearchProps {
  query?: string;
  filters?: {
    level?: string;
    duration?: string;
    tuition?: [number, number];
  };
}

export function useProgramSearch(props: UseProgramSearchProps = {}) {
  const {
    data,
    isLoading,
    error,
    fetchNextPage,
    hasNextPage,
  } = useInfiniteQuery({
    queryKey: ["programs", props],
    queryFn: ({ pageParam = 1 }) => 
      searchPrograms({ ...props, page: pageParam }),
    getNextPageParam: (lastPage) => 
      lastPage.hasNextPage ? lastPage.nextPage : undefined,
    initialPageSize: 20,
  });

  const programs = data?.pages.flatMap((page) => page.programs) ?? [];

  return {
    programs,
    isLoading,
    error,
    hasNextPage: !!hasNextPage,
    fetchNextPage,
  };
}